pub(crate) struct FlowDdlEvent {
event_type: &'static str,
catalog_name: Option<String>,
flow_name: Option<String>,
flow_id: Option<u32>,
payload: Option<FlowDdlPayload>,
}Expand description
A Flow DDL event with a schema shared by every lifecycle trigger.
Fields
event_type: &'static strcatalog_name: Option<String>flow_name: Option<String>flow_id: Option<u32>payload: Option<FlowDdlPayload>Implementations
Sourceimpl FlowDdlEvent
impl FlowDdlEvent
Sourcepub(crate) fn create_submitted(
catalog_name: &str,
flow_name: &str,
intent: CreateFlowEventIntent,
) -> Self
pub(crate) fn create_submitted( catalog_name: &str, flow_name: &str, intent: CreateFlowEventIntent, ) -> Self
Builds the bounded event emitted when creating a Flow is submitted.
Sourcepub(crate) fn drop_submitted(
catalog_name: &str,
flow_name: &str,
flow_id: u32,
drop_if_exists: bool,
) -> Self
pub(crate) fn drop_submitted( catalog_name: &str, flow_name: &str, flow_id: u32, drop_if_exists: bool, ) -> Self
Builds the bounded event emitted when dropping a Flow is submitted.
Sourcepub(crate) fn create_lifecycle(catalog_name: &str, flow_name: &str) -> Self
pub(crate) fn create_lifecycle(catalog_name: &str, flow_name: &str) -> Self
Builds a Create Flow lifecycle event with its submitted locator.
Sourcepub(crate) fn create_succeeded(
catalog_name: &str,
flow_name: &str,
flow_id: Option<u32>,
) -> Self
pub(crate) fn create_succeeded( catalog_name: &str, flow_name: &str, flow_id: Option<u32>, ) -> Self
Builds a successful Create Flow event with its submitted locator and resolved ID.
Sourcepub(crate) fn drop_lifecycle(
catalog_name: &str,
flow_name: &str,
flow_id: u32,
) -> Self
pub(crate) fn drop_lifecycle( catalog_name: &str, flow_name: &str, flow_id: u32, ) -> Self
Builds a Drop Flow lifecycle event with its submitted locator.
fn lifecycle( event_type: &'static str, catalog_name: &str, flow_name: &str, ) -> Self